pub type DirectByteChannel<Backends> = DirectChannel<Backends, ByteBridge<Backends>>;Expand description
A local channel with a simple byte bridge between backends. It transfers tensors between backends via the underlying tensor data.
Aliased Type
pub struct DirectByteChannel<Backends> { /* private fields */ }